@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -100,15 +100,15 @@ if ($poller_id < 0) {
 		array($poller_id));
 }
 
-if (sizeof($pollers)) {
+if (cacti_sizeof($pollers)) {
 	foreach ($pollers as $poller) {
-		replicate_out($poller['id'], $class);
-
 		db_execute_prepared('UPDATE poller
 			SET last_sync = NOW(), requires_sync=""
 			WHERE id = ?',
 			array($poller['id']));
 
+		replicate_out($poller['id'], $class);
+
 		cacti_log('STATS: Poller ID ' . $poller['id'] . ' fully Replicated', false, 'POLLER');
 	}
 } else {
@@ -127,7 +127,7 @@ function display_help () {
 	display_version();
 
 	print "\nA utility to fully Synchronize Remote Data Collectors.\n\n";
-	print "usage: poller_output_empty.php [--poller=N] [--class=all|data|auth|settings]\n\n";
+	print "usage: poller_replicate.php [--poller=N] [--class=all|data|auth|settings]\n\n";
 	print "Optional:\n";
 	print "    --poller=N  The numeric id of the poller to replicate out.  Otherwise all\n";
 	print "                pollers.  The default is all.\n";
