@@ -1,7 +1,7 @@
 /*
  * JS Storage Plugin
  *
- * Copyright (c) 2016 Julien Maurel
+ * Copyright (c) 2019 Julien Maurel
  *
  * Licensed under the MIT license:
  * http://www.opensource.org/licenses/mit-license.php
@@ -9,7 +9,7 @@
  * Project home:
  * https://github.com/julien-maurel/js-storage
  *
- * Version: 1.0.2
+ * Version: 1.1.0
  */
 (function (factory) {
     var registeredInModuleLoader = false;
@@ -74,6 +74,9 @@
             // Get first level
             try {
                 ret = JSON.parse(s.getItem(a0));
+                if (!ret) {
+                    throw new ReferenceError(a0 + ' is not defined in this storage');
+                }
             } catch (e) {
                 throw new ReferenceError(a0 + ' is not defined in this storage');
             }
@@ -81,7 +84,7 @@
             for (i = 1; i < l - 1; i++) {
                 ret = ret[a[i]];
                 if (ret === undefined) {
-                    throw new ReferenceError([].slice.call(a, 1, i + 1).join('.') + ' is not defined in this storage');
+                    throw new ReferenceError([].slice.call(a, 0, i + 1).join('.') + ' is not defined in this storage');
                 }
             }
             // If last argument is an array, return an object with value for each item in this array
@@ -344,7 +347,7 @@
             localStorage: _extend({}, apis.localStorage, {_ns: name}),
             sessionStorage: _extend({}, apis.sessionStorage, {_ns: name})
         };
-        if (typeof Cookies !== 'undefined') {
+        if (cookies_available) {
             if (!window.cookieStorage.getItem(name)) {
                 window.cookieStorage.setItem(name, '{}');
             }
@@ -416,8 +419,9 @@
         return result;
     }
 
-    // Check if storages are natively available on browser
+    // Check if storages are natively available on browser and check is js-cookie is present
     var storage_available = _testStorage('localStorage');
+    var cookies_available = typeof Cookies !== 'undefined';
 
     // Namespace object
     var storage = {
@@ -426,7 +430,6 @@
         _callMethod: function (f, a) {
             a = Array.prototype.slice.call(a);
             var p = [], a0 = a[0];
-
             if (this._ns) {
                 p.push(this._ns);
             }
@@ -441,6 +444,9 @@
         alwaysUseJson: false,
         // Get items. If no parameters and storage have a namespace, return all namespace
         get: function () {
+            if (!storage_available && !cookies_available){
+                return null;
+            }
             return this._callMethod(_get, arguments);
         },
         // Set items
@@ -449,6 +455,9 @@
             if (l < 1 || !_isPlainObject(a0) && l < 2) {
                 throw new Error('Minimum 2 arguments must be given or first parameter must be an object');
             }
+            if (!storage_available && !cookies_available){
+                return null;
+            }
             // If first argument is an object and storage is a namespace storage, set values individually
             if (_isPlainObject(a0) && this._ns) {
                 for (var i in a0) {
@@ -471,10 +480,16 @@
             if (arguments.length < 1) {
                 throw new Error('Minimum 1 argument must be given');
             }
+            if (!storage_available && !cookies_available){
+                return null;
+            }
             return this._callMethod(_remove, arguments);
         },
         // Delete all items
         removeAll: function (reinit_ns) {
+            if (!storage_available && !cookies_available){
+                return null;
+            }
             if (this._ns) {
                 this._callMethod(_set, [{}]);
                 return true;
@@ -484,6 +499,9 @@
         },
         // Items empty
         isEmpty: function () {
+            if (!storage_available && !cookies_available){
+                return null;
+            }
             return this._callMethod(_isEmpty, arguments);
         },
         // Items exists
@@ -491,16 +509,22 @@
             if (arguments.length < 1) {
                 throw new Error('Minimum 1 argument must be given');
             }
+            if (!storage_available && !cookies_available){
+                return null;
+            }
             return this._callMethod(_isSet, arguments);
         },
         // Get keys of items
         keys: function () {
+            if (!storage_available && !cookies_available){
+                return null;
+            }
             return this._callMethod(_keys, arguments);
         }
     };
 
     // Use js-cookie for compatibility with old browsers and give access to cookieStorage
-    if (typeof Cookies !== 'undefined') {
+    if (cookies_available) {
         // sessionStorage is valid for one window/tab. To simulate that with cookie, we set a name for the window and use it for the name of the cookie
         if (!window.name) {
             window.name = Math.floor(Math.random() * 100000000);
@@ -511,8 +535,9 @@
             _expires: null,
             _path: null,
             _domain: null,
+            _secure: false,
             setItem: function (n, v) {
-                Cookies.set(this._prefix + n, v, {expires: this._expires, path: this._path, domain: this._domain});
+                Cookies.set(this._prefix + n, v, {expires: this._expires, path: this._path, domain: this._domain, secure: this._secure});
             },
             getItem: function (n) {
                 return Cookies.get(this._prefix + n);
@@ -542,6 +567,10 @@
                 this._domain = d;
                 return this;
             },
+            setSecure: function (s) {
+                this._secure = s;
+                return this;
+            },
             setConf: function (c) {
                 if (c.path) {
                     this._path = c.path;
@@ -549,6 +578,9 @@
                 if (c.domain) {
                     this._domain = c.domain;
                 }
+                if (c.secure) {
+                    this._secure = c.secure;
+                }
                 if (c.expires) {
                     this._expires = c.expires;
                 }
@@ -556,14 +588,19 @@
             },
             setDefaultConf: function () {
                 this._path = this._domain = this._expires = null;
+                this._secure = false;
             }
         };
         if (!storage_available) {
             window.localCookieStorage = _extend({}, cookie_storage, {
                 _prefix: cookie_local_prefix,
-                _expires: 365 * 10
+                _expires: 365 * 10,
+                _secure: true
+            });
+            window.sessionCookieStorage = _extend({}, cookie_storage, {
+                _prefix: cookie_session_prefix + window.name + '_',
+                _secure: true
             });
-            window.sessionCookieStorage = _extend({}, cookie_storage, {_prefix: cookie_session_prefix + window.name + '_'});
         }
         window.cookieStorage = _extend({}, cookie_storage);
         // cookieStorage API
@@ -581,6 +618,10 @@
                 window.cookieStorage.setDomain(d);
                 return this;
             },
+            setSecure: function (s) {
+                window.cookieStorage.setSecure(s);
+                return this;
+            },
             setConf: function (c) {
                 window.cookieStorage.setConf(c);
                 return this;
@@ -597,11 +638,6 @@
         return _createNamespace(ns);
     };
     if (storage_available) {
-        // About alwaysUseJson
-        // By default, all values are string on html storages and the plugin don't use json to store simple values (strings, int, float...)
-        // So by default, if you do storage.setItem('test',2), value in storage will be "2", not 2
-        // If you set this property to true, all values set with the plugin will be stored as json to have typed values in any cases
-
         // localStorage API
         apis.localStorage = _extend({}, storage, {_type: 'localStorage'});
         // sessionStorage API
@@ -625,6 +661,10 @@
             apis.namespaceStorages = {};
         }
     };
+    // About alwaysUseJson
+    // By default, all values are string on html storages and the plugin don't use json to store simple values (strings, int, float...)
+    // So by default, if you do storage.setItem('test',2), value in storage will be "2", not 2
+    // If you set this property to true, all values set with the plugin will be stored as json to have typed values in any cases
     apis.alwaysUseJsonInStorage = function (value) {
         storage.alwaysUseJson = value;
         apis.localStorage.alwaysUseJson = value;
