@@ -593,6 +593,10 @@ function is_graph_template_allowed($graph_template_id, $user = 0) {
  */
 function is_view_allowed($view = 'show_tree') {
 	if (read_config_option('auth_method') != 0) {
+		if (!isset($_SESSION['sess_user_id'])) {
+			return false;
+		}
+
 		$values = array_rekey(
 			db_fetch_assoc_prepared("SELECT DISTINCT $view
 				FROM user_auth_group AS uag
@@ -1466,7 +1470,7 @@ function get_allowed_graph_templates($sql_where = '', $order_by = 'gt.name', $li
 		cacti_log('Obtaining \'Graph Template\' cache', false, 'WEBUI', POLLER_VERBOSITY_HIGH);
 		$cached = get_cached_allowed_type($hash, $init_rows);
 
-		if (is_array($cached) && sizeof($cached)) {
+		if (is_array($cached) && cacti_sizeof($cached)) {
 			cacti_log('Found Valid \'Graph Template\' priming cache', false, 'WEBUI', POLLER_VERBOSITY_HIGH);
 			return $cached;
 		}
@@ -1877,7 +1881,7 @@ function get_allowed_devices($sql_where = '', $order_by = 'description', $limit
 	if ($host_id > 0) {
 		$sql_where .= ($sql_where != '' ? ' AND ' : 'WHERE ') . " h.id=$host_id";
 	} else {
-		if (sizeof($cached)) {
+		if (cacti_sizeof($cached)) {
 			return db_fetch_assoc("SELECT *
 				FROM host AS h
 				$sql_where" .
