@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -143,6 +143,10 @@ function dsdebug_poller_bottom() {
 	/* take time and log performance data */
 	$start = microtime(true);
 
+	if (!db_table_exists('data_debug')) {
+		return true;
+	}
+
 	$checks = db_fetch_assoc('SELECT *
 		FROM data_debug
 		WHERE `done` = 0');
@@ -245,7 +249,7 @@ function dsdebug_poller_bottom() {
 				if ($c['started'] < time() - ($dtd['rrd_step'] * 5)) {
 					$c['done'] = 1;
 					$c['issue'][] = __('Debug not completed after 5 pollings');
-					$c['issue'][] = __('Failed fields: ') . implode($f, ', ');
+					$c['issue'][] = __('Failed fields: ') . implode(', ', $f);
 
 					$total_issues++;
 				}
